# PyLucidMQ

## What is it

This is the python implementation and client library using LucidMQ

## Installation

Deploy wheel binary to pypi so people can pip install.

## Examples

For now look at test.py
